==> java-micro-1.0-20180526.093605-18-sources.jar: com/xunyi/micro/grpc/sleuth/TraceClientInterceptor.java <==
package com.xunyi.micro.grpc.sleuth;

import io.grpc.*;
import org.springframework.cloud.sleuth.Span;
import org.springframework.cloud.sleuth.SpanInjector;
import org.springframework.cloud.sleuth.Tracer;

/**
 *
 */
public class TraceClientInterceptor implements ClientInterceptor {

    private Tracer tracer;
    private SpanInjector<Metadata> spanInjector;

    public TraceClientInterceptor(Tracer tracer, SpanInjector<Metadata> spanInjector) {
        this.tracer = tracer;
        this.spanInjector = spanInjector;
    }

    @Override
    public <ReqT, RespT> ClientCall<ReqT, RespT> interceptCall(MethodDescriptor<ReqT, RespT> method, CallOptions callOptions, Channel next) {
        return new ClientInterceptors.CheckedForwardingClientCall<ReqT, RespT>(next.newCall(method, callOptions)) {
            @Override
            protected void checkedStart(ClientCall.Listener<RespT> listener, Metadata metadata) throws Exception {
                Span parentSpan = tracer.getCurrentSpan();
                String operationName = method.getFullMethodName();
                final Span span = tracer.createSpan(operationName, parentSpan);
                //TODO: 添加rpc client标签  添加grpc组件标签
                spanInjector.inject(span, metadata);
                delegate().start(new ForwardingClientCallListener.SimpleForwardingClientCallListener<RespT>(listener) {
                    @Override
                    public void onReady() {
                        span.logEvent(Span.CLIENT_SEND);
                        super.onReady();
                    }

//                    @Override
//                    public void onClose(Status status, Metadata trailers) {
//                        span.logEvent(Span.Cli);
//                        tracer.close(span);
//                        super.onClose(status, trailers);
//                    }

                    @Override
                    public void onMessage(RespT message) {
                        span.logEvent(Span.CLIENT_RECV);
                        tracer.close(span);
                        super.onMessage(message);
                    }
                }, metadata);
            }
        };
    }
}

==> java-micro-1.1-20180823.065328-6-sources.jar: com/xunyi/micro/grpc/sleuth/TraceClientInterceptor.java <==
package com.xunyi.micro.grpc.sleuth;

import io.grpc.*;
import org.springframework.cloud.sleuth.Span;
import org.springframework.cloud.sleuth.SpanInjector;
import org.springframework.cloud.sleuth.Tracer;

/**
 *
 */
public class TraceClientInterceptor implements ClientInterceptor {

    private Tracer tracer;
    private SpanInjector<Metadata> spanInjector;

    public TraceClientInterceptor(Tracer tracer, SpanInjector<Metadata> spanInjector) {
        this.tracer = tracer;
        this.spanInjector = spanInjector;
    }

    @Override
    public <ReqT, RespT> ClientCall<ReqT, RespT> interceptCall(MethodDescriptor<ReqT, RespT> method, CallOptions callOptions, Channel next) {
        return new ClientInterceptors.CheckedForwardingClientCall<ReqT, RespT>(next.newCall(method, callOptions)) {
            @Override
            protected void checkedStart(ClientCall.Listener<RespT> listener, Metadata metadata) throws Exception {
                Span parentSpan = tracer.getCurrentSpan();
                String operationName = method.getFullMethodName();
                final Span span = tracer.createSpan(operationName, parentSpan);
                //TODO: 添加rpc client标签  添加grpc组件标签
                spanInjector.inject(span, metadata);
                delegate().start(new ForwardingClientCallListener.SimpleForwardingClientCallListener<RespT>(listener) {
                    @Override
                    public void onReady() {
                        span.logEvent(Span.CLIENT_SEND);
                        super.onReady();
                    }

                    @Override
                    public void onClose(Status status, Metadata trailers) {
                        span.logEvent(Span.CLIENT_RECV);
                        tracer.close(span);
                        super.onClose(status, trailers);
                    }

//                    @Override
//                    public void onMessage(RespT message) {
//                        span.logEvent(Span.CLIENT_RECV);
//                        tracer.close(span);
//                        super.onMessage(message);
//                    }
                }, metadata);
            }
        };
    }
}
